@@ -110,6 +110,146 @@ class WebClient(BaseClient):
             "admin.apps.restricted.list", http_verb="GET", params=kwargs
         )
 
+    def admin_conversations_create(
+        self, *, is_private: bool, name: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Create a public or private channel-based conversation.
+
+        Args:
+            is_private (bool): When true, creates a private channel instead of a public channel
+            name (str): Name of the public or private channel to create.
+            org_wide (bool): When true, the channel will be available org-wide.
+                Note: if the channel is not org_wide=true, you must specify a team_id for this channel
+            team_id (str): The workspace to create the channel in.
+                Note: this argument is required unless you set org_wide=true.
+
+        """
+        kwargs.update({"is_private": is_private, "name": name})
+        return self.api_call("admin.conversations.create", json=kwargs)
+
+    def admin_conversations_delete(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Delete a public or private channel.
+
+        Args:
+            channel_id (str): The channel to delete.
+
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.delete", json=kwargs)
+
+    def admin_conversations_invite(
+        self, *, channel_id: str, user_ids: Union[str, List[str]], **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Invite a user to a public or private channel.
+
+        Args:
+            channel_id (str): The channel that the users will be invited to.
+            user_ids (str or list): The users to invite.
+        """
+        kwargs.update({"channel_id": channel_id})
+        if isinstance(user_ids, list):
+            kwargs.update({"user_ids": ",".join(user_ids)})
+        else:
+            kwargs.update({"user_ids": user_ids})
+        # NOTE: the endpoint is unable to handle Content-Type: application/json as of Sep 3, 2020.
+        return self.api_call("admin.conversations.invite", params=kwargs)
+
+    def admin_conversations_archive(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Archive a public or private channel.
+
+        Args:
+            channel_id (str): The channel to archive.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.archive", json=kwargs)
+
+    def admin_conversations_unarchive(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Unarchive a public or private channel.
+
+        Args:
+            channel_id (str): The channel to unarchive.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.unarchive", json=kwargs)
+
+    def admin_conversations_rename(
+        self, *, channel_id: str, name: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Rename a public or private channel.
+
+        Args:
+            channel_id (str): The channel to rename.
+            name (str): The name to rename the channel to.
+        """
+        kwargs.update({"channel_id": channel_id, "name": name})
+        return self.api_call("admin.conversations.rename", json=kwargs)
+
+    def admin_conversations_search(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Search for public or private channels in an Enterprise organization."""
+        return self.api_call("admin.conversations.search", json=kwargs)
+
+    def admin_conversations_convertToPrivate(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Convert a public channel to a private channel.
+
+        Args:
+            channel_id (str): The channel to convert to private.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.convertToPrivate", json=kwargs)
+
+    def admin_conversations_setConversationPrefs(
+        self, *, channel_id: str, prefs: Union[str, dict], **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the posting permissions for a public or private channel.
+
+        Args:
+            channel_id (str): The channel to set the prefs for
+            prefs (str or dict): The prefs for this channel in a stringified JSON format.
+        """
+        kwargs.update({"channel_id": channel_id, "prefs": prefs})
+        return self.api_call("admin.conversations.setConversationPrefs", json=kwargs)
+
+    def admin_conversations_getConversationPrefs(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Get conversation preferences for a public or private channel.
+
+        Args:
+            channel_id (str): The channel to get the preferences for.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.getConversationPrefs", json=kwargs)
+
+    def admin_conversations_disconnectShared(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Disconnect a connected channel from one or more workspaces.
+
+        Args:
+            channel_id (str): The channel to be disconnected from some workspaces.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.disconnectShared", json=kwargs)
+
+    def admin_conversations_ekm_listOriginalConnectedChannelInfo(
+        self, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """List all disconnected channels—i.e.,
+        channels that were once connected to other workspaces and then disconnected—and
+        the corresponding original channel IDs for key revocation with EKM.
+        """
+        return self.api_call(
+            "admin.conversations.ekm.listOriginalConnectedChannelInfo", params=kwargs
+        )
+
     def admin_conversations_restrictAccess_addGroup(
         self, *, channel_id: str, group_id: str, **kwargs
     ) -> Union[Future, SlackResponse]:
@@ -171,10 +311,30 @@ class WebClient(BaseClient):
             params=kwargs,
         )
 
-    def admin_conversations_setTeams(self, **kwargs) -> Union[Future, SlackResponse]:
-        """Set the workspaces in an Enterprise grid org that connect to a channel."""
+    def admin_conversations_setTeams(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the workspaces in an Enterprise grid org that connect to a channel.
+
+        Args:
+            channel_id (str): The encoded channel_id to add or remove to workspaces.
+
+        """
+        kwargs.update({"channel_id": channel_id})
         return self.api_call("admin.conversations.setTeams", json=kwargs)
 
+    def admin_conversations_getTeams(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the workspaces in an Enterprise grid org that connect to a channel.
+
+        Args:
+            channel_id (str): The channel to determine connected workspaces within the organization for.
+
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.getTeams", json=kwargs)
+
     def admin_emoji_add(self, **kwargs) -> Union[Future, SlackResponse]:
         """Add an emoji."""
         return self.api_call("admin.emoji.add", http_verb="GET", params=kwargs)
@@ -206,6 +366,18 @@ class WebClient(BaseClient):
         kwargs.update({"user_id": user_id})
         return self.api_call("admin.users.session.reset", json=kwargs)
 
+    def admin_users_session_invalidate(
+        self, *, session_id: str, team_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Invalidate a single session for a user by session_id.
+
+        Args:
+            session_id (str): The ID of a session
+            team_id (str): ID of the team that the session belongs to
+        """
+        kwargs.update({"session_id": session_id, "team_id": team_id})
+        return self.api_call("admin.users.session.invalidate", params=kwargs)
+
     def admin_inviteRequests_approve(
         self, *, invite_request_id: str, **kwargs
     ) -> Union[Future, SlackResponse]:
@@ -540,6 +712,30 @@ class WebClient(BaseClient):
         """Checks API calling code."""
         return self.api_call("api.test", json=kwargs)
 
+    def apps_event_authorizations_list(
+        self, event_context: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Get a list of authorizations for the given event context.
+        Each authorization represents an app installation that the event is visible to.
+
+        Args:
+            event_context (str): You'll receive an event_context identifying an event in each event payload sent to your app.
+        """
+        kwargs.update({"event_context": event_context})
+        return self.api_call("apps.event.authorizations.list", params=kwargs)
+
+    def apps_uninstall(
+        self, client_id: str, client_secret: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Uninstalls your app from a workspace.
+
+        Args:
+            client_id (str): Issued when you created your application. e.g. '56579136444.26251006572'
+            client_secret (str): Issued when you created your application. e.g. 'f25b5ceaf8a3c2a2c4f52bb4f0b0499e'
+        """
+        kwargs.update({"client_id": client_id, "client_secret": client_secret})
+        return self.api_call("apps.uninstall", params=kwargs)
+
     def auth_revoke(self, **kwargs) -> Union[Future, SlackResponse]:
         """Revokes a token."""
         return self.api_call("auth.revoke", http_verb="GET", params=kwargs)
@@ -565,7 +761,7 @@ class WebClient(BaseClient):
                 e.g. 'https://example.com/calls/1234567890'
         """
         kwargs.update({"external_unique_id": external_unique_id, "join_url": join_url})
-        _update_call_participants(kwargs, kwargs.get("users", None))
+        _update_call_participants(kwargs, kwargs.get("users"))
         return self.api_call("calls.add", http_verb="POST", params=kwargs)
 
     def calls_end(
@@ -1331,7 +1527,7 @@ class WebClient(BaseClient):
             )
 
         if file:
-            if "filename" not in kwargs:
+            if "filename" not in kwargs and isinstance(file, str):
                 # use the local filename if filename is missing
                 kwargs["filename"] = file.split(os.path.sep)[-1]
             return self.api_call("files.upload", files={"file": file}, data=kwargs)
@@ -2154,3 +2350,60 @@ class WebClient(BaseClient):
         else:
             kwargs.update({"view": view})
         return self.api_call("views.publish", json=kwargs)
+
+    def workflows_stepCompleted(
+        self, *, workflow_step_execute_id: str, outputs: dict = None, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Indicate a successful outcome of a workflow step's execution.
+        Args:
+            workflow_step_execute_id (str): A unique identifier of the workflow step to be updated.
+                e.g. 'add_task'
+            outputs (dict): A key-value object of outputs from your step.
+                e.g. { 'task_name': 'Task Name' }
+        """
+        kwargs.update({"workflow_step_execute_id": workflow_step_execute_id})
+        if outputs:
+            kwargs.update({"outputs": outputs})
+
+        return self.api_call("workflows.stepCompleted", json=kwargs)
+
+    def workflows_stepFailed(
+        self, *, workflow_step_execute_id: str, error: dict, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Indicate an unsuccessful outcome of a workflow step's execution.
+        Args:
+            workflow_step_execute_id (str): A unique identifier of the workflow step to be updated.
+                e.g. 'add_task'
+            error (dict): A dict with a message property that contains a human readable error message
+                e.g. { message: 'Step failed to execute.' }
+        """
+        kwargs.update(
+            {"workflow_step_execute_id": workflow_step_execute_id, "error": error}
+        )
+        return self.api_call("workflows.stepFailed", json=kwargs)
+
+    def workflows_updateStep(
+        self,
+        *,
+        workflow_step_edit_id: str,
+        inputs: dict = None,
+        outputs: list = None,
+        **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Update the configuration for a workflow extension step.
+        Args:
+            workflow_step_edit_id (str): A unique identifier of the workflow step to be updated.
+                e.g. 'add_task'
+            inputs (dict): A key-value object of inputs required from a user during step configuration.
+                e.g. { 'title': { 'value': 'The Title' }, 'submitter': { 'value': 'The Submitter' } }
+            outputs (list): A list of output objects used during step execution.
+                e.g. [{ 'type': 'text', 'name': 'title', 'label': 'Title' }]
+        """
+        kwargs.update({"workflow_step_edit_id": workflow_step_edit_id})
+
+        if inputs:
+            kwargs.update({"inputs": inputs})
+        if outputs:
+            kwargs.update({"outputs": outputs})
+
+        return self.api_call("workflows.updateStep", json=kwargs)
